"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.generate = void 0;
var utils_1 = require("./utils");
function generate(ast) {
    return ast.children
        .map(function (node) {
        if ((0, utils_1.isElementNode)(node)) {
            if (node.tag === 'template') {
                return generateTemplate(node);
            }
        }
        return node.loc.source;
    })
        .join('\n\n');
}
exports.generate = generate;
function generateTemplate(node) {
    return "<template>".concat(node.children
        .map(function (node) { return generateNode(node); })
        .join(''), "</template>");
}
function generateNode(node) {
    if ((0, utils_1.isElementNode)(node)) {
        return generateElement(node);
    }
    return node.loc.source;
}
function generateElement(node) {
    if (node.isSelfClosing) {
        return "<".concat(node.tag, " ").concat(generateAttrs(node), " />");
    }
    var children = node.children.map(function (child) { return generateNode(child); }).join('');
    return "<".concat(node.tag, " ").concat(generateAttrs(node), ">").concat(children, "</").concat(node.tag, ">");
}
function generateAttrs(node) {
    var props = node.props;
    return props
        .map(function (prop) {
        if (prop.type === 6 /* NodeTypes.ATTRIBUTE */) {
            if (prop.value) {
                return "".concat(prop.name, "=\"").concat(prop.value.content, "\"");
            }
            else {
                return prop.name;
            }
        }
        return prop.loc.source;
    })
        .join(' ');
}
