"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.injectTraceIdVue = void 0;
var parse_1 = require("./parse");
var traverse_1 = require("./traverse");
var generate_1 = require("./generate");
var utils_1 = require("./utils");
var path_1 = __importDefault(require("path"));
var ATTR_ID = 'data-source';
/**
 * inject Trace Id in jsx code
 */
function injectTraceIdVue(vue, options) {
    var filepath = options.filepath, opener = options.opener;
    var ast = (0, parse_1.parseSfc)(vue);
    (0, traverse_1.traverse)(ast, {
        pre: function (node) {
            var _a, _b, _c;
            if ((0, utils_1.isElementNode)(node)) {
                var line = node.loc.start.line;
                var column = node.loc.start.column;
                var uri = "".concat(filepath, ":").concat(line, ":").concat(column);
                if (opener.type === 'github') {
                    var relativeFilepath = path_1.default.relative((_a = opener.cwd) !== null && _a !== void 0 ? _a : process.cwd(), filepath);
                    uri = "".concat(opener.url, "/blob/").concat((_b = opener.branch) !== null && _b !== void 0 ? _b : 'main', "/").concat(relativeFilepath, "#L").concat(line);
                }
                else if (opener.type === 'jetbrains') {
                    uri = "http://localhost:".concat((_c = opener.port) !== null && _c !== void 0 ? _c : 63342, "/api/file/").concat(uri);
                }
                node.props.push({
                    type: 6 /* NodeTypes.ATTRIBUTE */,
                    name: ATTR_ID,
                    value: {
                        type: 2 /* NodeTypes.TEXT */,
                        content: uri,
                    },
                });
            }
            return true;
        },
    });
    var code = (0, generate_1.generate)(ast);
    return { code: code };
}
exports.injectTraceIdVue = injectTraceIdVue;
